pub trait ActionNodeCodeGen {
// Required methods
fn generate_code(&self, node_id: &str) -> String;
fn required_imports(&self) -> Vec<&'static str>;
fn required_dependencies(&self) -> Vec<(&'static str, &'static str)>;
}Expand description
Trait for generating Rust code from action node configurations
Required Methods
Sourcefn generate_code(&self, node_id: &str) -> String
fn generate_code(&self, node_id: &str) -> String
Generate the Rust code for this action node
Sourcefn required_imports(&self) -> Vec<&'static str>
fn required_imports(&self) -> Vec<&'static str>
Generate any required imports for this action node
Sourcefn required_dependencies(&self) -> Vec<(&'static str, &'static str)>
fn required_dependencies(&self) -> Vec<(&'static str, &'static str)>
Generate any required Cargo dependencies for this action node